# Definicion de instancia

param conductores := 2;
param viajes := 7;

set K := { 1 .. conductores };
set V := { 1 .. viajes };

set A := { <1, 2>, <1, 6>, <1, 7>, <2, 3>, <5, 2>, <6, 2>, <6, 3>, <7, 3>, <4, 5>, <5, 6>, <5, 7>, <6, 7> };
set Aplus := { <1, 2>, <1, 3>, <1, 6>, <1, 7>, <2, 3>, <4, 2>, <5, 2>, <6, 2>, <5, 3>, <6, 3>, <7, 3>, <4, 5>, <4, 6>, <4, 7>, <5, 6>, <5, 7>, <6, 7> };
set J := { <1, 3>, <4, 2>, <5, 3>, <4, 6>, <4, 7> };
param c[J] := <1, 3> 78, <4, 2> 0, <5, 3> 68, <4, 6> 0, <4, 7> 5;

# Definiciones adicionales

set complemento := { <u, v> in (V cross V) with u < v and (not <u, v> in Aplus) and (not <v, u> in Aplus)};
defset A_dplus(v) := { <j> in V with <v, j> in A };
defset A_dminus(v) := { <i> in V with <i, v> in A };
defset Aplus_dplus(v) := { <j> in V with <v, j> in Aplus };
defset Aplus_dminus(v) := { <i> in V with <i, v> in Aplus };

# Variables

var x[K * V] binary;
var y[J] binary;

# Funcion objetivo

minimize cost:
   sum <u, v> in J with c[u, v] > 0: c[u, v] * y[u, v];

# Restricciones

subto asignacion:
   forall <v> in V: sum <k> in K: x[k, v] == 1;

subto compatibilidad:
   forall <u, v> in complemento: forall <k> in K: x[k, u] + x[k, v] <= 1;

subto viajes_no_inmediatos_plus:
   forall <u, v> in Aplus\A: forall <k> in K: sum <w> in A_dplus(u): x[k, w] >= x[k, u] + x[k, v] - 1;

subto viajes_no_inmediatos_minus:
   forall <u, v> in Aplus\A: forall <k> in K: sum <w> in A_dminus(v): x[k, w] >= x[k, u] + x[k, v] - 1;

subto primer_ultimo_viajes:
   forall <u, v> in Aplus\J: forall <k> in K: x[k, u] + x[k, v] - (sum <w> in Aplus_dminus(u): x[k, w]) - (sum <w> in Aplus_dplus(v): x[k, w]) <= 1;

subto vincula_x_y:
   forall <u, v> in J with c[u, v] > 0: forall <k> in K: y[u, v] >= x[k, u] + x[k, v] - 1 - (sum <w> in Aplus_dminus(u): x[k, w]) - (sum <w> in Aplus_dplus(v): x[k, w]);
